@@ -360,7 +360,8 @@ cxxExchComp::add(const cxxExchComp & addee, LDBLE extensive)
 	this->la = f1 * this->la + f2 * addee.la;
 	this->charge_balance += addee.charge_balance * extensive;
 
-	if (this->phase_name != addee.phase_name)
+	//if (this->phase_name != addee.phase_name)
+	if (Phreeqc::strcmp_nocase(this->phase_name.c_str(), addee.phase_name.c_str()) != 0)
 	{
 		std::ostringstream oss;
 		oss <<
@@ -374,7 +375,8 @@ cxxExchComp::add(const cxxExchComp & addee, LDBLE extensive)
 		this->phase_proportion =
 			this->phase_proportion * f1 + addee.phase_proportion * f2;
 	}
-	if (this->rate_name != addee.rate_name)
+	//if (this->rate_name != addee.rate_name)
+	if (Phreeqc::strcmp_nocase(this->rate_name.c_str(), addee.rate_name.c_str()) != 0)
 	{
 		std::ostringstream oss;
 		oss <<
